[![build status](https://travis-ci.com/amirhessam88/ml-algs.svg?branch=master)](https://travis-ci.com/github/amirhessam88/ml-algs)
[![License](https://img.shields.io/github/license/amirhessam88/ml-algs)](https://github.com/amirhessam88/ml-algs/blob/master/LICENSE)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mlalgs)](https://pypi.org/project/mlalgs/)
![PyPI Version](https://img.shields.io/pypi/v/mlalgs)
[![Issues](https://img.shields.io/github/issues/amirhessam88/ml-algs)](https://github.com/amirhessam88/ml-algs/issues)
[![Forks](https://img.shields.io/github/forks/amirhessam88/ml-algs)](https://github.com/amirhessam88/ml-algs/network/members)
[![Stars](https://img.shields.io/github/stars/amirhessam88/ml-algs)](https://github.com/amirhessam88/ml-algs/stargazers)

<p align="center">
<a href="https://www.amirhessam.com/">
  <img src="https://raw.githubusercontent.com/amirhessam88/ml-algs/master/assets/design/logo.png" width="250"></img></a>
</p>

<h1 align="center">
    Machine Learning Algorithms from Scratch in Python
</h1>


## Installation

First, install Python 3.6 from https://www.python.org, and then run:

```
pip install mlalgs
```

## Citation
If you use the library in academic work, please consider citing
https://doi.org/10.1117/12.2304418 .

### Bibtex Entry:
```bib
@inproceedings{tahmassebi2018ideeple,
  title={ideeple: Deep learning in a flash},
  author={Tahmassebi, Amirhessam},
  booktitle={Disruptive Technologies in Information Sciences},
  volume={10652},
  pages={106520S},
  year={2018},
  organization={International Society for Optics and Photonics}
}
```
### APA Entry:

Tahmassebi, A. (2018, May). ideeple: Deep learning in a flash. In Disruptive
Technologies in Information Sciences (Vol. 10652, p. 106520S). International
Society for Optics and Photonics.

